@@ -39,7 +39,7 @@ try:
     SERIES_STD.encode(sys.__stdout__.encoding)
 except UnicodeEncodeError:  # pragma: no cover(Non-unicode Terminal)
     SERIES_STD = u' |'
-except AttributeError:  # pragma: no cover(Non-standard Terminal)
+except (AttributeError, TypeError):  # pragma: no cover(Non-standard Terminal)
     pass
 
 COLORS_16 = ('black', 'red', 'green', 'yellow', 'blue', 'magenta', 'cyan', 'white',
@@ -375,7 +375,7 @@ class Counter(BaseCounter):
             - bright_white
             - bright_yellow
 
-        See this `chart <https://blessed.readthedocs.io/en/latest/colors.html#id3>`_
+        See this `chart <https://blessed.readthedocs.io/en/stable/colors.html#id3>`_
         for a complete list of supported color strings.
 
         .. note::
